"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Item(google.protobuf.message.Message):
    """排行榜列表项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAVOURITE_FIELD_NUMBER: builtins.int
    PUB_DATE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PTS_FIELD_NUMBER: builtins.int
    COOPERATION_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面url"""

    param: typing.Text
    """参数(稿件avid)"""

    uri: typing.Text
    """跳转uri"""

    redirect_url: typing.Text
    """重定向url"""

    goto: typing.Text
    """跳转类型
    av:视频稿件
    """

    play: builtins.int
    """播放数"""

    danmaku: builtins.int
    """弹幕数"""

    mid: builtins.int
    """UP主mid"""

    name: typing.Text
    """UP主昵称"""

    face: typing.Text
    """UP主头像url"""

    reply: builtins.int
    """评论数"""

    favourite: builtins.int
    """收藏数"""

    pub_date: builtins.int
    """发布时间"""

    rid: builtins.int
    """分区tid"""

    rname: typing.Text
    """子分区名"""

    duration: builtins.int
    """视频总时长"""

    like: builtins.int
    """点赞数"""

    cid: builtins.int
    """1P cid"""

    pts: builtins.int
    """综合评分"""

    cooperation: typing.Text
    """合作视频文案"""

    attribute: builtins.int
    """属性位
    0:未关注 1:已关注
    """

    follower: builtins.int
    """UP主粉丝数"""

    @property
    def official_verify(self) -> global___OfficialVerify:
        """UP主认证信息"""
        pass
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """同一UP收起子项列表"""
        pass
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        param: typing.Text = ...,
        uri: typing.Text = ...,
        redirect_url: typing.Text = ...,
        goto: typing.Text = ...,
        play: builtins.int = ...,
        danmaku: builtins.int = ...,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        reply: builtins.int = ...,
        favourite: builtins.int = ...,
        pub_date: builtins.int = ...,
        rid: builtins.int = ...,
        rname: typing.Text = ...,
        duration: builtins.int = ...,
        like: builtins.int = ...,
        cid: builtins.int = ...,
        pts: builtins.int = ...,
        cooperation: typing.Text = ...,
        attribute: builtins.int = ...,
        follower: builtins.int = ...,
        official_verify: typing.Optional[global___OfficialVerify] = ...,
        children: typing.Optional[typing.Iterable[global___Item]] = ...,
        relation: typing.Optional[global___Relation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify",b"official_verify","relation",b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","children",b"children","cid",b"cid","cooperation",b"cooperation","cover",b"cover","danmaku",b"danmaku","duration",b"duration","face",b"face","favourite",b"favourite","follower",b"follower","goto",b"goto","like",b"like","mid",b"mid","name",b"name","official_verify",b"official_verify","param",b"param","play",b"play","pts",b"pts","pub_date",b"pub_date","redirect_url",b"redirect_url","relation",b"relation","reply",b"reply","rid",b"rid","rname",b"rname","title",b"title","uri",b"uri"]) -> None: ...
global___Item = Item

class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    -1:无认证 0:个人认证 1:机构认证
    """

    desc: typing.Text
    """认证描述"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","type",b"type"]) -> None: ...
global___OfficialVerify = OfficialVerify

class RankAllResultReq(google.protobuf.message.Message):
    """全站排行榜-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDER_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    order: typing.Text
    """必须为"all" """

    pn: builtins.int
    """页码
    默认1页
    """

    ps: builtins.int
    """每页项数
    默认100项，最大100
    """

    def __init__(self,
        *,
        order: typing.Text = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["order",b"order","pn",b"pn","ps",b"ps"]) -> None: ...
global___RankAllResultReq = RankAllResultReq

class RankListReply(google.protobuf.message.Message):
    """排行榜信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """排行榜列表"""
        pass
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___Item]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items"]) -> None: ...
global___RankListReply = RankListReply

class RankRegionResultReq(google.protobuf.message.Message):
    """分区排行榜-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    rid: builtins.int
    """一级分区tid(二级分区不可用)
    0:全站
    """

    pn: builtins.int
    """页码
    默认1页
    """

    ps: builtins.int
    """每页项数
    默认100项，最大100
    """

    def __init__(self,
        *,
        rid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pn",b"pn","ps",b"ps","rid",b"rid"]) -> None: ...
global___RankRegionResultReq = RankRegionResultReq

class Relation(google.protobuf.message.Message):
    """关系信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态id
    1:未关注 2:已关注 3:被关注 4:互相关注
    """

    is_follow: builtins.int
    """是否关注"""

    is_followed: builtins.int
    """是否粉丝"""

    def __init__(self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow",b"is_follow","is_followed",b"is_followed","status",b"status"]) -> None: ...
global___Relation = Relation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RoomStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _RoomStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RoomStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Pause: _RoomStatus.ValueType  # 0
    """暂停:"""

    Play: _RoomStatus.ValueType  # 1
    """播放:"""

    End: _RoomStatus.ValueType  # 2
    """终止:"""

class RoomStatus(_RoomStatus, metaclass=_RoomStatusEnumTypeWrapper):
    """"""
    pass

Pause: RoomStatus.ValueType  # 0
"""暂停:"""

Play: RoomStatus.ValueType  # 1
"""播放:"""

End: RoomStatus.ValueType  # 2
"""终止:"""

global___RoomStatus = RoomStatus


class RoomEvent(google.protobuf.message.Message):
    """推送选项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_STATUS_FIELD_NUMBER: builtins.int
    ROOM_MESSAGE_FIELD_NUMBER: builtins.int
    room_status: global___RoomStatus.ValueType
    """RoomStatus 类型"""

    room_message: typing.Text
    """"""

    def __init__(self,
        *,
        room_status: global___RoomStatus.ValueType = ...,
        room_message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_message",b"room_message","room_status",b"room_status"]) -> None: ...
global___RoomEvent = RoomEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Notify(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_ID_FIELD_NUMBER: builtins.int
    MSG_TYPE_FIELD_NUMBER: builtins.int
    RECEIVER_UID_FIELD_NUMBER: builtins.int
    RECEIVER_TYPE_FIELD_NUMBER: builtins.int
    STORY_VERSION_FIELD_NUMBER: builtins.int
    OP_HASH_FIELD_NUMBER: builtins.int
    OP_SENDER_FIELD_NUMBER: builtins.int
    OP_CONTENT_FIELD_NUMBER: builtins.int
    msg_id: builtins.int
    """消息唯一标示"""

    msg_type: builtins.int
    """消息类型"""

    receiver_uid: builtins.int
    """接收方uid"""

    receiver_type: builtins.int
    """接收方类型"""

    story_version: builtins.int
    """故事的版本"""

    op_hash: builtins.int
    """操作结果的hash值"""

    op_sender: builtins.int
    """操作产生用户的uid"""

    op_content: typing.Text
    """patch内容"""

    def __init__(self,
        *,
        msg_id: builtins.int = ...,
        msg_type: builtins.int = ...,
        receiver_uid: builtins.int = ...,
        receiver_type: builtins.int = ...,
        story_version: builtins.int = ...,
        op_hash: builtins.int = ...,
        op_sender: builtins.int = ...,
        op_content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_id",b"msg_id","msg_type",b"msg_type","op_content",b"op_content","op_hash",b"op_hash","op_sender",b"op_sender","receiver_type",b"receiver_type","receiver_uid",b"receiver_uid","story_version",b"story_version"]) -> None: ...
global___Notify = Notify



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Action:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Action.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _Action.ValueType  # 0
    """"""

    UPDATE: _Action.ValueType  # 1
    """"""

    DELETE: _Action.ValueType  # 2
    """"""

class Action(_Action, metaclass=_ActionEnumTypeWrapper):
    """"""
    pass

UNKNOWN: Action.ValueType  # 0
""""""

UPDATE: Action.ValueType  # 1
""""""

DELETE: Action.ValueType  # 2
""""""

global___Action = Action


class AuthReq(google.protobuf.message.Message):
    """鉴权请求，通过authorization验证绑定用户mid"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GUID_FIELD_NUMBER: builtins.int
    CONN_ID_FIELD_NUMBER: builtins.int
    LAST_MSG_ID_FIELD_NUMBER: builtins.int
    guid: typing.Text
    """冷启动id，算法uuid，重新起启会变"""

    conn_id: typing.Text
    """连接id，算法uuid，重连会变"""

    last_msg_id: builtins.int
    """最后收到的消息id，用于过虑重连后获取未读的消息"""

    def __init__(self,
        *,
        guid: typing.Text = ...,
        conn_id: typing.Text = ...,
        last_msg_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conn_id",b"conn_id","guid",b"guid","last_msg_id",b"last_msg_id"]) -> None: ...
global___AuthReq = AuthReq

class AuthResp(google.protobuf.message.Message):
    """鉴权返回"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AuthResp = AuthResp

class BroadcastFrame(google.protobuf.message.Message):
    """target_path:
      "/" Service-Name "/" {method name} 参考 gRPC Request Path
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPTIONS_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___FrameOption:
        """请求消息信息"""
        pass
    target_path: typing.Text
    """业务target_path"""

    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """业务pb内容"""
        pass
    def __init__(self,
        *,
        options: typing.Optional[global___FrameOption] = ...,
        target_path: typing.Text = ...,
        body: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body",b"body","options",b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body",b"body","options",b"options","target_path",b"target_path"]) -> None: ...
global___BroadcastFrame = BroadcastFrame

class FrameOption(google.protobuf.message.Message):
    """message_id: 
      client: 本次连接唯一的消息id，可用于回执
      server: 唯一消息id，可用于上报或者回执
    sequence:
      client: 客户端应该每次请求时frame seq++，会返回对应的对称req/resp
      server: 服务端下行消息，只会返回默认值：0
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    IS_ACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    """消息id"""

    sequence: builtins.int
    """frame序号"""

    is_ack: builtins.bool
    """是否进行消息回执(发出MessageAckReq)
    downstream 上只有服务端设置为true，客户端响应
    upstream   上只有客户端设置为true，服务端响应
    响应帧禁止设置is_ack，协议上禁止循环
    通常只有业务帧才可能设置is_ack, 因为协议栈(例如心跳、鉴权)另有响应约定
    """

    @property
    def status(self) -> bilibili.rpc.status_pb2.Status:
        """业务状态码"""
        pass
    ack_origin: typing.Text
    """业务ack来源, 仅downstream时候由服务端填写."""

    timestamp: builtins.int
    """"""

    def __init__(self,
        *,
        message_id: builtins.int = ...,
        sequence: builtins.int = ...,
        is_ack: builtins.bool = ...,
        status: typing.Optional[bilibili.rpc.status_pb2.Status] = ...,
        ack_origin: typing.Text = ...,
        timestamp: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_origin",b"ack_origin","is_ack",b"is_ack","message_id",b"message_id","sequence",b"sequence","status",b"status","timestamp",b"timestamp"]) -> None: ...
global___FrameOption = FrameOption

class HeartbeatReq(google.protobuf.message.Message):
    """心跳请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___HeartbeatReq = HeartbeatReq

class HeartbeatResp(google.protobuf.message.Message):
    """心跳返回"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___HeartbeatResp = HeartbeatResp

class MessageAckReq(google.protobuf.message.Message):
    """消息回执"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACK_ID_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    ack_id: builtins.int
    """消息id"""

    ack_origin: typing.Text
    """ack来源，由业务指定用于埋点跟踪"""

    target_path: typing.Text
    """消息对应的target_path，方便业务区分和监控统计"""

    def __init__(self,
        *,
        ack_id: builtins.int = ...,
        ack_origin: typing.Text = ...,
        target_path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_id",b"ack_id","ack_origin",b"ack_origin","target_path",b"target_path"]) -> None: ...
global___MessageAckReq = MessageAckReq

class TargetPath(google.protobuf.message.Message):
    """target_path"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TARGET_PATHS_FIELD_NUMBER: builtins.int
    @property
    def target_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """需要订阅的target_paths"""
        pass
    def __init__(self,
        *,
        target_paths: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_paths",b"target_paths"]) -> None: ...
global___TargetPath = TargetPath



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlayerArgs(google.protobuf.message.Message):
    """视频秒开参数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """流版本"""

    fnval: builtins.int
    """流类型"""

    force_host: builtins.int
    """返回url是否强制使用域名
    0:不强制使用域名 1:http域名 2:https域名
    """

    def __init__(self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","qn",b"qn"]) -> None: ...
global___PlayerArgs = PlayerArgs



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DanmukuEvent(google.protobuf.message.Message):
    """实时弹幕事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ELEMS_FIELD_NUMBER: builtins.int
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
        pass
    def __init__(self,
        *,
        elems: typing.Optional[typing.Iterable[global___DanmakuElem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["elems",b"elems"]) -> None: ...
global___DanmukuEvent = DanmukuEvent

class DanmakuElem(google.protobuf.message.Message):
    """弹幕条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    MID_HASH_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕dmid"""

    progress: builtins.int
    """弹幕出现位置(单位为ms)"""

    mode: builtins.int
    """弹幕类型"""

    fontsize: builtins.int
    """弹幕字号"""

    color: builtins.int
    """弹幕颜色"""

    mid_hash: typing.Text
    """发送着mid hash"""

    content: typing.Text
    """弹幕正文"""

    ctime: builtins.int
    """发送时间"""

    action: typing.Text
    """弹幕动作"""

    pool: builtins.int
    """弹幕池"""

    id_str: typing.Text
    """弹幕id str"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        progress: builtins.int = ...,
        mode: builtins.int = ...,
        fontsize: builtins.int = ...,
        color: builtins.int = ...,
        mid_hash: typing.Text = ...,
        content: typing.Text = ...,
        ctime: builtins.int = ...,
        action: typing.Text = ...,
        pool: builtins.int = ...,
        id_str: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","color",b"color","content",b"content","ctime",b"ctime","fontsize",b"fontsize","id",b"id","id_str",b"id_str","mid_hash",b"mid_hash","mode",b"mode","pool",b"pool","progress",b"progress"]) -> None: ...
global___DanmakuElem = DanmakuElem

class CommandDm(google.protobuf.message.Message):
    """互动弹幕"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""

    oid: builtins.int
    """对象视频cid"""

    mid: builtins.int
    """发送者mid"""

    type: builtins.int
    """"""

    command: typing.Text
    """互动弹幕指令"""

    content: typing.Text
    """互动弹幕正文"""

    state: builtins.int
    """弹幕状态"""

    progress: builtins.int
    """出现时间"""

    ctime: typing.Text
    """创建时间"""

    mtime: typing.Text
    """发布时间"""

    extra: typing.Text
    """扩展json数据"""

    idStr: typing.Text
    """弹幕id str类型"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        type: builtins.int = ...,
        command: typing.Text = ...,
        content: typing.Text = ...,
        state: builtins.int = ...,
        progress: builtins.int = ...,
        ctime: typing.Text = ...,
        mtime: typing.Text = ...,
        extra: typing.Text = ...,
        idStr: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","content",b"content","ctime",b"ctime","extra",b"extra","id",b"id","idStr",b"idStr","mid",b"mid","mtime",b"mtime","oid",b"oid","progress",b"progress","state",b"state","type",b"type"]) -> None: ...
global___CommandDm = CommandDm



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.ad_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Base(google.protobuf.message.Message):
    """条目基本信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    CARD_GOTO_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    THREE_POINT_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    IDX_FIELD_NUMBER: builtins.int
    AD_INFO_FIELD_NUMBER: builtins.int
    MASK_FIELD_NUMBER: builtins.int
    FROM_TYPE_FIELD_NUMBER: builtins.int
    THREE_POINT_V2_FIELD_NUMBER: builtins.int
    THREE_POINT_V3_FIELD_NUMBER: builtins.int
    DESC_BUTTON_FIELD_NUMBER: builtins.int
    THREE_POINT_V4_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """卡片类型"""

    card_goto: typing.Text
    """卡片跳转类型?"""

    goto: typing.Text
    """跳转类型
    av:视频稿件 mid:用户空间
    """

    param: typing.Text
    """目标参数"""

    cover: typing.Text
    """封面url"""

    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转uri"""

    @property
    def three_point(self) -> global___ThreePoint:
        """"""
        pass
    @property
    def args(self) -> global___Args:
        """"""
        pass
    @property
    def player_args(self) -> global___PlayerArgs:
        """"""
        pass
    idx: builtins.int
    """条目排位序号"""

    @property
    def ad_info(self) -> bilibili.app.card.v1.ad_pb2.AdInfo:
        """"""
        pass
    @property
    def mask(self) -> global___Mask:
        """"""
        pass
    from_type: typing.Text
    """来源标识
    recommend:推荐 operation:管理?
    """

    @property
    def three_point_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointV2]:
        """"""
        pass
    @property
    def three_point_v3(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointV3]:
        """"""
        pass
    @property
    def desc_button(self) -> global___Button:
        """"""
        pass
    @property
    def three_point_v4(self) -> global___ThreePointV4:
        """三点v4"""
        pass
    def __init__(self,
        *,
        card_type: typing.Text = ...,
        card_goto: typing.Text = ...,
        goto: typing.Text = ...,
        param: typing.Text = ...,
        cover: typing.Text = ...,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        three_point: typing.Optional[global___ThreePoint] = ...,
        args: typing.Optional[global___Args] = ...,
        player_args: typing.Optional[global___PlayerArgs] = ...,
        idx: builtins.int = ...,
        ad_info: typing.Optional[bilibili.app.card.v1.ad_pb2.AdInfo] = ...,
        mask: typing.Optional[global___Mask] = ...,
        from_type: typing.Text = ...,
        three_point_v2: typing.Optional[typing.Iterable[global___ThreePointV2]] = ...,
        three_point_v3: typing.Optional[typing.Iterable[global___ThreePointV3]] = ...,
        desc_button: typing.Optional[global___Button] = ...,
        three_point_v4: typing.Optional[global___ThreePointV4] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_info",b"ad_info","args",b"args","desc_button",b"desc_button","mask",b"mask","player_args",b"player_args","three_point",b"three_point","three_point_v4",b"three_point_v4"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_info",b"ad_info","args",b"args","card_goto",b"card_goto","card_type",b"card_type","cover",b"cover","desc_button",b"desc_button","from_type",b"from_type","goto",b"goto","idx",b"idx","mask",b"mask","param",b"param","player_args",b"player_args","three_point",b"three_point","three_point_v2",b"three_point_v2","three_point_v3",b"three_point_v3","three_point_v4",b"three_point_v4","title",b"title","uri",b"uri"]) -> None: ...
global___Base = Base

class Button(google.protobuf.message.Message):
    """按钮信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文案"""

    param: typing.Text
    """参数"""

    uri: typing.Text
    """"""

    event: typing.Text
    """事件"""

    selected: builtins.int
    """"""

    type: builtins.int
    """类型"""

    event_v2: typing.Text
    """事件v2"""

    @property
    def relation(self) -> global___Relation:
        """关系信息"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        param: typing.Text = ...,
        uri: typing.Text = ...,
        event: typing.Text = ...,
        selected: builtins.int = ...,
        type: builtins.int = ...,
        event_v2: typing.Text = ...,
        relation: typing.Optional[global___Relation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation",b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event","event_v2",b"event_v2","param",b"param","relation",b"relation","selected",b"selected","text",b"text","type",b"type","uri",b"uri"]) -> None: ...
global___Button = Button

class ThreePoint(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISLIKE_REASONS_FIELD_NUMBER: builtins.int
    FEEDBACKS_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def dislike_reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
        pass
    @property
    def feedbacks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
        pass
    watch_later: builtins.int
    """稍后再看"""

    def __init__(self,
        *,
        dislike_reasons: typing.Optional[typing.Iterable[global___DislikeReason]] = ...,
        feedbacks: typing.Optional[typing.Iterable[global___DislikeReason]] = ...,
        watch_later: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_reasons",b"dislike_reasons","feedbacks",b"feedbacks","watch_later",b"watch_later"]) -> None: ...
global___ThreePoint = ThreePoint

class DislikeReason(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    name: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","name",b"name"]) -> None: ...
global___DislikeReason = DislikeReason

class Args(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    TNAME_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CONVERGE_TYPE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    up_id: builtins.int
    """"""

    up_name: typing.Text
    """"""

    rid: builtins.int
    """"""

    rname: typing.Text
    """"""

    tid: builtins.int
    """"""

    tname: typing.Text
    """"""

    track_id: typing.Text
    """"""

    state: typing.Text
    """"""

    converge_type: builtins.int
    """"""

    aid: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        up_id: builtins.int = ...,
        up_name: typing.Text = ...,
        rid: builtins.int = ...,
        rname: typing.Text = ...,
        tid: builtins.int = ...,
        tname: typing.Text = ...,
        track_id: typing.Text = ...,
        state: typing.Text = ...,
        converge_type: builtins.int = ...,
        aid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","converge_type",b"converge_type","rid",b"rid","rname",b"rname","state",b"state","tid",b"tid","tname",b"tname","track_id",b"track_id","type",b"type","up_id",b"up_id","up_name",b"up_name"]) -> None: ...
global___Args = Args

class PlayerArgs(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_LIVE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    is_live: builtins.int
    """"""

    aid: builtins.int
    """"""

    cid: builtins.int
    """"""

    sub_type: builtins.int
    """"""

    room_id: builtins.int
    """"""

    ep_id: builtins.int
    """"""

    is_preview: builtins.int
    """"""

    type: typing.Text
    """"""

    duration: builtins.int
    """"""

    season_id: builtins.int
    """"""

    def __init__(self,
        *,
        is_live: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        sub_type: builtins.int = ...,
        room_id: builtins.int = ...,
        ep_id: builtins.int = ...,
        is_preview: builtins.int = ...,
        type: typing.Text = ...,
        duration: builtins.int = ...,
        season_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","duration",b"duration","ep_id",b"ep_id","is_live",b"is_live","is_preview",b"is_preview","room_id",b"room_id","season_id",b"season_id","sub_type",b"sub_type","type",b"type"]) -> None: ...
global___PlayerArgs = PlayerArgs

class Mask(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AVATAR_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    @property
    def avatar(self) -> global___Avatar:
        """"""
        pass
    @property
    def button(self) -> global___Button:
        """"""
        pass
    def __init__(self,
        *,
        avatar: typing.Optional[global___Avatar] = ...,
        button: typing.Optional[global___Button] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","button",b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","button",b"button"]) -> None: ...
global___Mask = Mask

class Avatar(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    DEFALUT_COVER_FIELD_NUMBER: builtins.int
    cover: typing.Text
    """"""

    text: typing.Text
    """"""

    uri: typing.Text
    """"""

    type: builtins.int
    """"""

    event: typing.Text
    """"""

    event_v2: typing.Text
    """"""

    defalut_cover: builtins.int
    """"""

    def __init__(self,
        *,
        cover: typing.Text = ...,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        type: builtins.int = ...,
        event: typing.Text = ...,
        event_v2: typing.Text = ...,
        defalut_cover: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","defalut_cover",b"defalut_cover","event",b"event","event_v2",b"event_v2","text",b"text","type",b"type","uri",b"uri"]) -> None: ...
global___Avatar = Avatar

class ThreePointV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    subtitle: typing.Text
    """"""

    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
        pass
    type: typing.Text
    """"""

    id: builtins.int
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        subtitle: typing.Text = ...,
        reasons: typing.Optional[typing.Iterable[global___DislikeReason]] = ...,
        type: typing.Text = ...,
        id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","reasons",b"reasons","subtitle",b"subtitle","title",b"title","type",b"type"]) -> None: ...
global___ThreePointV2 = ThreePointV2

class ThreePointV3(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SELECTED_ICON_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DEFAULT_ID_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    selected_title: typing.Text
    """"""

    subtitle: typing.Text
    """"""

    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
        pass
    type: typing.Text
    """"""

    id: builtins.int
    """"""

    selected: builtins.int
    """"""

    icon: typing.Text
    """"""

    selected_icon: typing.Text
    """"""

    url: typing.Text
    """"""

    default_id: builtins.int
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        selected_title: typing.Text = ...,
        subtitle: typing.Text = ...,
        reasons: typing.Optional[typing.Iterable[global___DislikeReason]] = ...,
        type: typing.Text = ...,
        id: builtins.int = ...,
        selected: builtins.int = ...,
        icon: typing.Text = ...,
        selected_icon: typing.Text = ...,
        url: typing.Text = ...,
        default_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_id",b"default_id","icon",b"icon","id",b"id","reasons",b"reasons","selected",b"selected","selected_icon",b"selected_icon","selected_title",b"selected_title","subtitle",b"subtitle","title",b"title","type",b"type","url",b"url"]) -> None: ...
global___ThreePointV3 = ThreePointV3

class ThreePointV4(google.protobuf.message.Message):
    """三点v4"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHARE_PLANE_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def share_plane(self) -> global___SharePlane:
        """分享面板信息"""
        pass
    @property
    def watch_later(self) -> global___WatchLater:
        """稍后再看"""
        pass
    def __init__(self,
        *,
        share_plane: typing.Optional[global___SharePlane] = ...,
        watch_later: typing.Optional[global___WatchLater] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_plane",b"share_plane","watch_later",b"watch_later"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_plane",b"share_plane","watch_later",b"watch_later"]) -> None: ...
global___ThreePointV4 = ThreePointV4

class SharePlane(google.protobuf.message.Message):
    """分享面板信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class ShareToEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.bool
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.bool = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SHARE_TO_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_ID_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    PLAY_NUMBER_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    share_subtitle: typing.Text
    """副标贴文案"""

    desc: typing.Text
    """备注"""

    cover: typing.Text
    """封面url"""

    aid: builtins.int
    """稿件avid"""

    bvid: typing.Text
    """稿件bvid"""

    @property
    def share_to(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.bool]:
        """允许分享方式"""
        pass
    author: typing.Text
    """UP主昵称"""

    author_id: builtins.int
    """UP主mid"""

    short_link: typing.Text
    """短连接"""

    play_number: typing.Text
    """播放次数文案"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        share_subtitle: typing.Text = ...,
        desc: typing.Text = ...,
        cover: typing.Text = ...,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        share_to: typing.Optional[typing.Mapping[typing.Text, builtins.bool]] = ...,
        author: typing.Text = ...,
        author_id: builtins.int = ...,
        short_link: typing.Text = ...,
        play_number: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","author",b"author","author_id",b"author_id","bvid",b"bvid","cover",b"cover","desc",b"desc","play_number",b"play_number","share_subtitle",b"share_subtitle","share_to",b"share_to","short_link",b"short_link","title",b"title"]) -> None: ...
global___SharePlane = SharePlane

class WatchLater(google.protobuf.message.Message):
    """稍后再看信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    bvid: typing.Text
    """稿件bvid"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","bvid",b"bvid"]) -> None: ...
global___WatchLater = WatchLater

class ReasonStyle(google.protobuf.message.Message):
    """标签框信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    ICON_NIGHT_URL_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_BG_URL_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    RIGHT_ICON_TYPE_FIELD_NUMBER: builtins.int
    LEFT_ICON_TYPE_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文案"""

    text_color: typing.Text
    """文字颜色"""

    bg_color: typing.Text
    """背景色"""

    border_color: typing.Text
    """边框色"""

    icon_url: typing.Text
    """图标url"""

    text_color_night: typing.Text
    """文字颜色-夜间"""

    bg_color_night: typing.Text
    """背景色-夜间"""

    border_color_night: typing.Text
    """边框色-夜间"""

    icon_night_url: typing.Text
    """图标url-夜间"""

    bg_style: builtins.int
    """背景风格id
    1:无背景 2:有背景
    """

    uri: typing.Text
    """"""

    icon_bg_url: typing.Text
    """"""

    event: typing.Text
    """"""

    event_v2: typing.Text
    """"""

    right_icon_type: builtins.int
    """"""

    left_icon_type: typing.Text
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        bg_color: typing.Text = ...,
        border_color: typing.Text = ...,
        icon_url: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        border_color_night: typing.Text = ...,
        icon_night_url: typing.Text = ...,
        bg_style: builtins.int = ...,
        uri: typing.Text = ...,
        icon_bg_url: typing.Text = ...,
        event: typing.Text = ...,
        event_v2: typing.Text = ...,
        right_icon_type: builtins.int = ...,
        left_icon_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_style",b"bg_style","border_color",b"border_color","border_color_night",b"border_color_night","event",b"event","event_v2",b"event_v2","icon_bg_url",b"icon_bg_url","icon_night_url",b"icon_night_url","icon_url",b"icon_url","left_icon_type",b"left_icon_type","right_icon_type",b"right_icon_type","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night","uri",b"uri"]) -> None: ...
global___ReasonStyle = ReasonStyle

class LikeButton(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    Aid: builtins.int
    """"""

    count: builtins.int
    """"""

    show_count: builtins.bool
    """"""

    event: typing.Text
    """"""

    selected: builtins.int
    """"""

    event_v2: typing.Text
    """"""

    def __init__(self,
        *,
        Aid: builtins.int = ...,
        count: builtins.int = ...,
        show_count: builtins.bool = ...,
        event: typing.Text = ...,
        selected: builtins.int = ...,
        event_v2: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Aid",b"Aid","count",b"count","event",b"event","event_v2",b"event_v2","selected",b"selected","show_count",b"show_count"]) -> None: ...
global___LikeButton = LikeButton

class Up(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    DESC_BUTTON_FIELD_NUMBER: builtins.int
    COOPERATION_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    name: typing.Text
    """"""

    desc: typing.Text
    """"""

    @property
    def avatar(self) -> global___Avatar:
        """"""
        pass
    official_icon: builtins.int
    """"""

    @property
    def desc_button(self) -> global___Button:
        """"""
        pass
    cooperation: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        desc: typing.Text = ...,
        avatar: typing.Optional[global___Avatar] = ...,
        official_icon: builtins.int = ...,
        desc_button: typing.Optional[global___Button] = ...,
        cooperation: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","desc_button",b"desc_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","cooperation",b"cooperation","desc",b"desc","desc_button",b"desc_button","id",b"id","name",b"name","official_icon",b"official_icon"]) -> None: ...
global___Up = Up

class Relation(google.protobuf.message.Message):
    """关系信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态"""

    is_follow: builtins.int
    """是否关注"""

    is_followed: builtins.int
    """是否粉丝"""

    def __init__(self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow",b"is_follow","is_followed",b"is_followed","status",b"status"]) -> None: ...
global___Relation = Relation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Notify(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """cid"""

    def __init__(self,
        *,
        cid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid"]) -> None: ...
global___Notify = Notify



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/community/service/dm/v1/dm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/community/service/dm/v1/dm.proto\x12 bilibili.community.service.dm.v1\"X\n\x0e\x42uzzwordConfig\x12\x46\n\x08keywords\x18\x01 \x03(\x0b\x32\x34.bilibili.community.service.dm.v1.BuzzwordShowConfig\"x\n\x12\x42uzzwordShowConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\x12\x13\n\x0b\x62uzzword_id\x18\x05 \x01(\x03\x12\x13\n\x0bschema_type\x18\x06 \x01(\x05\"\xa1\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\r\n\x05idStr\x18\n \x01(\t\"P\n\rDanmakuAIFlag\x12?\n\x08\x64m_flags\x18\x01 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuFlag\"\xd6\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x0f\n\x07midHash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06weight\x18\t \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\n \x01(\t\x12\x0c\n\x04pool\x18\x0b \x01(\x05\x12\r\n\x05idStr\x18\x0c \x01(\t\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\")\n\x0b\x44\x61nmakuFlag\x12\x0c\n\x04\x64mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\"K\n\x11\x44\x61nmakuFlagConfig\x12\x10\n\x08rec_flag\x18\x01 \x01(\x05\x12\x10\n\x08rec_text\x18\x02 \x01(\t\x12\x12\n\nrec_switch\x18\x03 \x01(\x05\"\xcc\x04\n\x18\x44\x61nmuDefaultPlayerConfig\x12)\n!player_danmaku_use_default_config\x18\x01 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12$\n\x1cinline_player_danmaku_switch\x18\x10 \x01(\x08\x12)\n!player_danmaku_senior_mode_switch\x18\x11 \x01(\x05\"\xfe\x05\n\x11\x44\x61nmuPlayerConfig\x12\x1d\n\x15player_danmaku_switch\x18\x01 \x01(\x08\x12\"\n\x1aplayer_danmaku_switch_save\x18\x02 \x01(\x08\x12)\n!player_danmaku_use_default_config\x18\x03 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12&\n\x1eplayer_danmaku_enableblocklist\x18\x10 \x01(\x08\x12$\n\x1cinline_player_danmaku_switch\x18\x11 \x01(\x08\x12$\n\x1cinline_player_danmaku_config\x18\x12 \x01(\x05\x12&\n\x1eplayer_danmaku_ios_switch_save\x18\x13 \x01(\x05\x12)\n!player_danmaku_senior_mode_switch\x18\x14 \x01(\x05\"K\n\x18\x44\x61nmuPlayerDynamicConfig\x12\x10\n\x08progress\x18\x01 \x01(\x05\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\"\xb1\x02\n\x15\x44\x61nmuPlayerViewConfig\x12\x61\n\x1d\x64\x61nmuku_default_player_config\x18\x01 \x01(\x0b\x32:.bilibili.community.service.dm.v1.DanmuDefaultPlayerConfig\x12R\n\x15\x64\x61nmuku_player_config\x18\x02 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmuPlayerConfig\x12\x61\n\x1d\x64\x61nmuku_player_dynamic_config\x18\x03 \x03(\x0b\x32:.bilibili.community.service.dm.v1.DanmuPlayerDynamicConfig\"\xab\x03\n\x14\x44\x61nmuWebPlayerConfig\x12\x11\n\tdm_switch\x18\x01 \x01(\x08\x12\x11\n\tai_switch\x18\x02 \x01(\x08\x12\x10\n\x08\x61i_level\x18\x03 \x01(\x05\x12\x10\n\x08\x62locktop\x18\x04 \x01(\x08\x12\x13\n\x0b\x62lockscroll\x18\x05 \x01(\x08\x12\x13\n\x0b\x62lockbottom\x18\x06 \x01(\x08\x12\x12\n\nblockcolor\x18\x07 \x01(\x08\x12\x14\n\x0c\x62lockspecial\x18\x08 \x01(\x08\x12\x14\n\x0cpreventshade\x18\t \x01(\x08\x12\r\n\x05\x64mask\x18\n \x01(\x08\x12\x0f\n\x07opacity\x18\x0b \x01(\x02\x12\x0e\n\x06\x64marea\x18\x0c \x01(\x05\x12\x11\n\tspeedplus\x18\r \x01(\x02\x12\x10\n\x08\x66ontsize\x18\x0e \x01(\x02\x12\x12\n\nscreensync\x18\x0f \x01(\x08\x12\x11\n\tspeedsync\x18\x10 \x01(\x08\x12\x12\n\nfontfamily\x18\x11 \x01(\t\x12\x0c\n\x04\x62old\x18\x12 \x01(\x08\x12\x12\n\nfontborder\x18\x13 \x01(\x05\x12\x11\n\tdraw_type\x18\x14 \x01(\t\x12\x1a\n\x12senior_mode_switch\x18\x15 \x01(\x05\"A\n\x0f\x44mExpoReportReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\r\n\x05spmid\x18\x04 \x01(\t\"\x11\n\x0f\x44mExpoReportRes\"\xfd\x0b\n\x11\x44mPlayerConfigReq\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x45\n\x06switch\x18\x02 \x01(\x0b\x32\x35.bilibili.community.service.dm.v1.PlayerDanmakuSwitch\x12N\n\x0bswitch_save\x18\x03 \x01(\x0b\x32\x39.bilibili.community.service.dm.v1.PlayerDanmakuSwitchSave\x12[\n\x12use_default_config\x18\x04 \x01(\x0b\x32?.bilibili.community.service.dm.v1.PlayerDanmakuUseDefaultConfig\x12\x61\n\x15\x61i_recommended_switch\x18\x05 \x01(\x0b\x32\x42.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedSwitch\x12_\n\x14\x61i_recommended_level\x18\x06 \x01(\x0b\x32\x41.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedLevel\x12I\n\x08\x62locktop\x18\x07 \x01(\x0b\x32\x37.bilibili.community.service.dm.v1.PlayerDanmakuBlocktop\x12O\n\x0b\x62lockscroll\x18\x08 \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockscroll\x12O\n\x0b\x62lockbottom\x18\t \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockbottom\x12S\n\rblockcolorful\x18\n \x01(\x0b\x32<.bilibili.community.service.dm.v1.PlayerDanmakuBlockcolorful\x12O\n\x0b\x62lockrepeat\x18\x0b \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockrepeat\x12Q\n\x0c\x62lockspecial\x18\x0c \x01(\x0b\x32;.bilibili.community.service.dm.v1.PlayerDanmakuBlockspecial\x12G\n\x07opacity\x18\r \x01(\x0b\x32\x36.bilibili.community.service.dm.v1.PlayerDanmakuOpacity\x12S\n\rscalingfactor\x18\x0e \x01(\x0b\x32<.bilibili.community.service.dm.v1.PlayerDanmakuScalingfactor\x12\x45\n\x06\x64omain\x18\x0f \x01(\x0b\x32\x35.bilibili.community.service.dm.v1.PlayerDanmakuDomain\x12\x43\n\x05speed\x18\x10 \x01(\x0b\x32\x34.bilibili.community.service.dm.v1.PlayerDanmakuSpeed\x12W\n\x0f\x65nableblocklist\x18\x11 \x01(\x0b\x32>.bilibili.community.service.dm.v1.PlayerDanmakuEnableblocklist\x12^\n\x19inlinePlayerDanmakuSwitch\x18\x12 \x01(\x0b\x32;.bilibili.community.service.dm.v1.InlinePlayerDanmakuSwitch\x12[\n\x12senior_mode_switch\x18\x13 \x01(\x0b\x32?.bilibili.community.service.dm.v1.PlayerDanmakuSeniorModeSwitch\"/\n\x0b\x44mSegConfig\x12\x11\n\tpage_size\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"\xa1\x01\n\x10\x44mSegMobileReply\x12<\n\x05\x65lems\x18\x01 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\x12\r\n\x05state\x18\x02 \x01(\x05\x12@\n\x07\x61i_flag\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.DanmakuAIFlag\"g\n\x0e\x44mSegMobileReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\x12\x16\n\x0eteenagers_mode\x18\x05 \x01(\x05\"]\n\rDmSegOttReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12<\n\x05\x65lems\x18\x02 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\"L\n\x0b\x44mSegOttReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\"]\n\rDmSegSDKReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12<\n\x05\x65lems\x18\x02 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\"L\n\x0b\x44mSegSDKReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\"\xc2\x05\n\x0b\x44mViewReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x39\n\x04mask\x18\x02 \x01(\x0b\x32+.bilibili.community.service.dm.v1.VideoMask\x12\x41\n\x08subtitle\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.VideoSubtitle\x12\x13\n\x0bspecial_dms\x18\x04 \x03(\t\x12\x44\n\x07\x61i_flag\x18\x05 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmakuFlagConfig\x12N\n\rplayer_config\x18\x06 \x01(\x0b\x32\x37.bilibili.community.service.dm.v1.DanmuPlayerViewConfig\x12\x16\n\x0esend_box_style\x18\x07 \x01(\x05\x12\r\n\x05\x61llow\x18\x08 \x01(\x08\x12\x11\n\tcheck_box\x18\t \x01(\t\x12\x1a\n\x12\x63heck_box_show_msg\x18\n \x01(\t\x12\x18\n\x10text_placeholder\x18\x0b \x01(\t\x12\x19\n\x11input_placeholder\x18\x0c \x01(\t\x12\x1d\n\x15report_filter_content\x18\r \x03(\t\x12\x41\n\x0b\x65xpo_report\x18\x0e \x01(\x0b\x32,.bilibili.community.service.dm.v1.ExpoReport\x12I\n\x0f\x62uzzword_config\x18\x0f \x01(\x0b\x32\x30.bilibili.community.service.dm.v1.BuzzwordConfig\x12\x42\n\x0b\x65xpressions\x18\x10 \x03(\x0b\x32-.bilibili.community.service.dm.v1.Expressions\"X\n\tDmViewReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x14\n\x0cis_hard_boot\x18\x05 \x01(\x05\"\xec\x03\n\x0e\x44mWebViewReply\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x11\n\ttext_side\x18\x03 \x01(\t\x12=\n\x06\x64m_sge\x18\x04 \x01(\x0b\x32-.bilibili.community.service.dm.v1.DmSegConfig\x12\x41\n\x04\x66lag\x18\x05 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmakuFlagConfig\x12\x13\n\x0bspecial_dms\x18\x06 \x03(\t\x12\x11\n\tcheck_box\x18\x07 \x01(\x08\x12\r\n\x05\x63ount\x18\x08 \x01(\x03\x12?\n\ncommandDms\x18\t \x03(\x0b\x32+.bilibili.community.service.dm.v1.CommandDm\x12M\n\rplayer_config\x18\n \x01(\x0b\x32\x36.bilibili.community.service.dm.v1.DanmuWebPlayerConfig\x12\x1d\n\x15report_filter_content\x18\x0b \x03(\t\x12\x42\n\x0b\x65xpressions\x18\x0c \x03(\x0b\x32-.bilibili.community.service.dm.v1.Expressions\"*\n\nExpoReport\x12\x1c\n\x14should_report_at_end\x18\x01 \x01(\x08\"d\n\nExpression\x12\x0f\n\x07keyword\x18\x01 \x03(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x38\n\x06period\x18\x03 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Period\"I\n\x0b\x45xpressions\x12:\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32,.bilibili.community.service.dm.v1.Expression\"$\n\x06Period\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\"*\n\x19InlinePlayerDanmakuSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\"0\n\x1fPlayerDanmakuAiRecommendedLevel\x12\r\n\x05value\x18\x01 \x01(\x08\"1\n PlayerDanmakuAiRecommendedSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockbottom\x12\r\n\x05value\x18\x01 \x01(\x08\"+\n\x1aPlayerDanmakuBlockcolorful\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockrepeat\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockscroll\x12\r\n\x05value\x18\x01 \x01(\x08\"*\n\x19PlayerDanmakuBlockspecial\x12\r\n\x05value\x18\x01 \x01(\x08\"&\n\x15PlayerDanmakuBlocktop\x12\r\n\x05value\x18\x01 \x01(\x08\"$\n\x13PlayerDanmakuDomain\x12\r\n\x05value\x18\x01 \x01(\x02\"-\n\x1cPlayerDanmakuEnableblocklist\x12\r\n\x05value\x18\x01 \x01(\x08\"%\n\x14PlayerDanmakuOpacity\x12\r\n\x05value\x18\x01 \x01(\x02\"+\n\x1aPlayerDanmakuScalingfactor\x12\r\n\x05value\x18\x01 \x01(\x02\".\n\x1dPlayerDanmakuSeniorModeSwitch\x12\r\n\x05value\x18\x01 \x01(\x05\"#\n\x12PlayerDanmakuSpeed\x12\r\n\x05value\x18\x01 \x01(\x05\"7\n\x13PlayerDanmakuSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x11\n\tcanIgnore\x18\x02 \x01(\x08\"(\n\x17PlayerDanmakuSwitchSave\x12\r\n\x05value\x18\x01 \x01(\x08\".\n\x1dPlayerDanmakuUseDefaultConfig\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x08Response\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd8\x01\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06id_str\x18\x02 \x01(\t\x12\x0b\n\x03lan\x18\x03 \x01(\t\x12\x0f\n\x07lan_doc\x18\x04 \x01(\t\x12\x14\n\x0csubtitle_url\x18\x05 \x01(\t\x12:\n\x06\x61uthor\x18\x06 \x01(\x0b\x32*.bilibili.community.service.dm.v1.UserInfo\x12<\n\x04type\x18\x07 \x01(\x0e\x32..bilibili.community.service.dm.v1.SubtitleType\"\\\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0c\n\x04rank\x18\x06 \x01(\x05\"S\n\tVideoMask\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\x0b\n\x03\x66ps\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x10\n\x08mask_url\x18\x05 \x01(\t\"o\n\rVideoSubtitle\x12\x0b\n\x03lan\x18\x01 \x01(\t\x12\x0e\n\x06lanDoc\x18\x02 \x01(\t\x12\x41\n\tsubtitles\x18\x03 \x03(\x0b\x32..bilibili.community.service.dm.v1.SubtitleItem*L\n\tDMAttrBit\x12\x14\n\x10\x44MAttrBitProtect\x10\x00\x12\x15\n\x11\x44MAttrBitFromLive\x10\x01\x12\x12\n\x0e\x44MAttrHighLike\x10\x02*\x1e\n\x0cSubtitleType\x12\x06\n\x02\x43\x43\x10\x00\x12\x06\n\x02\x41I\x10\x01\x32\xa0\x05\n\x02\x44M\x12s\n\x0b\x44mSegMobile\x12\x30.bilibili.community.service.dm.v1.DmSegMobileReq\x1a\x32.bilibili.community.service.dm.v1.DmSegMobileReply\x12\x64\n\x06\x44mView\x12+.bilibili.community.service.dm.v1.DmViewReq\x1a-.bilibili.community.service.dm.v1.DmViewReply\x12q\n\x0e\x44mPlayerConfig\x12\x33.bilibili.community.service.dm.v1.DmPlayerConfigReq\x1a*.bilibili.community.service.dm.v1.Response\x12j\n\x08\x44mSegOtt\x12-.bilibili.community.service.dm.v1.DmSegOttReq\x1a/.bilibili.community.service.dm.v1.DmSegOttReply\x12j\n\x08\x44mSegSDK\x12-.bilibili.community.service.dm.v1.DmSegSDKReq\x1a/.bilibili.community.service.dm.v1.DmSegSDKReply\x12t\n\x0c\x44mExpoReport\x12\x31.bilibili.community.service.dm.v1.DmExpoReportReq\x1a\x31.bilibili.community.service.dm.v1.DmExpoReportResb\x06proto3')

_DMATTRBIT = DESCRIPTOR.enum_types_by_name['DMAttrBit']
DMAttrBit = enum_type_wrapper.EnumTypeWrapper(_DMATTRBIT)
_SUBTITLETYPE = DESCRIPTOR.enum_types_by_name['SubtitleType']
SubtitleType = enum_type_wrapper.EnumTypeWrapper(_SUBTITLETYPE)
DMAttrBitProtect = 0
DMAttrBitFromLive = 1
DMAttrHighLike = 2
CC = 0
AI = 1


_BUZZWORDCONFIG = DESCRIPTOR.message_types_by_name['BuzzwordConfig']
_BUZZWORDSHOWCONFIG = DESCRIPTOR.message_types_by_name['BuzzwordShowConfig']
_COMMANDDM = DESCRIPTOR.message_types_by_name['CommandDm']
_DANMAKUAIFLAG = DESCRIPTOR.message_types_by_name['DanmakuAIFlag']
_DANMAKUELEM = DESCRIPTOR.message_types_by_name['DanmakuElem']
_DANMAKUFLAG = DESCRIPTOR.message_types_by_name['DanmakuFlag']
_DANMAKUFLAGCONFIG = DESCRIPTOR.message_types_by_name['DanmakuFlagConfig']
_DANMUDEFAULTPLAYERCONFIG = DESCRIPTOR.message_types_by_name['DanmuDefaultPlayerConfig']
_DANMUPLAYERCONFIG = DESCRIPTOR.message_types_by_name['DanmuPlayerConfig']
_DANMUPLAYERDYNAMICCONFIG = DESCRIPTOR.message_types_by_name['DanmuPlayerDynamicConfig']
_DANMUPLAYERVIEWCONFIG = DESCRIPTOR.message_types_by_name['DanmuPlayerViewConfig']
_DANMUWEBPLAYERCONFIG = DESCRIPTOR.message_types_by_name['DanmuWebPlayerConfig']
_DMEXPOREPORTREQ = DESCRIPTOR.message_types_by_name['DmExpoReportReq']
_DMEXPOREPORTRES = DESCRIPTOR.message_types_by_name['DmExpoReportRes']
_DMPLAYERCONFIGREQ = DESCRIPTOR.message_types_by_name['DmPlayerConfigReq']
_DMSEGCONFIG = DESCRIPTOR.message_types_by_name['DmSegConfig']
_DMSEGMOBILEREPLY = DESCRIPTOR.message_types_by_name['DmSegMobileReply']
_DMSEGMOBILEREQ = DESCRIPTOR.message_types_by_name['DmSegMobileReq']
_DMSEGOTTREPLY = DESCRIPTOR.message_types_by_name['DmSegOttReply']
_DMSEGOTTREQ = DESCRIPTOR.message_types_by_name['DmSegOttReq']
_DMSEGSDKREPLY = DESCRIPTOR.message_types_by_name['DmSegSDKReply']
_DMSEGSDKREQ = DESCRIPTOR.message_types_by_name['DmSegSDKReq']
_DMVIEWREPLY = DESCRIPTOR.message_types_by_name['DmViewReply']
_DMVIEWREQ = DESCRIPTOR.message_types_by_name['DmViewReq']
_DMWEBVIEWREPLY = DESCRIPTOR.message_types_by_name['DmWebViewReply']
_EXPOREPORT = DESCRIPTOR.message_types_by_name['ExpoReport']
_EXPRESSION = DESCRIPTOR.message_types_by_name['Expression']
_EXPRESSIONS = DESCRIPTOR.message_types_by_name['Expressions']
_PERIOD = DESCRIPTOR.message_types_by_name['Period']
_INLINEPLAYERDANMAKUSWITCH = DESCRIPTOR.message_types_by_name['InlinePlayerDanmakuSwitch']
_PLAYERDANMAKUAIRECOMMENDEDLEVEL = DESCRIPTOR.message_types_by_name['PlayerDanmakuAiRecommendedLevel']
_PLAYERDANMAKUAIRECOMMENDEDSWITCH = DESCRIPTOR.message_types_by_name['PlayerDanmakuAiRecommendedSwitch']
_PLAYERDANMAKUBLOCKBOTTOM = DESCRIPTOR.message_types_by_name['PlayerDanmakuBlockbottom']
_PLAYERDANMAKUBLOCKCOLORFUL = DESCRIPTOR.message_types_by_name['PlayerDanmakuBlockcolorful']
_PLAYERDANMAKUBLOCKREPEAT = DESCRIPTOR.message_types_by_name['PlayerDanmakuBlockrepeat']
_PLAYERDANMAKUBLOCKSCROLL = DESCRIPTOR.message_types_by_name['PlayerDanmakuBlockscroll']
_PLAYERDANMAKUBLOCKSPECIAL = DESCRIPTOR.message_types_by_name['PlayerDanmakuBlockspecial']
_PLAYERDANMAKUBLOCKTOP = DESCRIPTOR.message_types_by_name['PlayerDanmakuBlocktop']
_PLAYERDANMAKUDOMAIN = DESCRIPTOR.message_types_by_name['PlayerDanmakuDomain']
_PLAYERDANMAKUENABLEBLOCKLIST = DESCRIPTOR.message_types_by_name['PlayerDanmakuEnableblocklist']
_PLAYERDANMAKUOPACITY = DESCRIPTOR.message_types_by_name['PlayerDanmakuOpacity']
_PLAYERDANMAKUSCALINGFACTOR = DESCRIPTOR.message_types_by_name['PlayerDanmakuScalingfactor']
_PLAYERDANMAKUSENIORMODESWITCH = DESCRIPTOR.message_types_by_name['PlayerDanmakuSeniorModeSwitch']
_PLAYERDANMAKUSPEED = DESCRIPTOR.message_types_by_name['PlayerDanmakuSpeed']
_PLAYERDANMAKUSWITCH = DESCRIPTOR.message_types_by_name['PlayerDanmakuSwitch']
_PLAYERDANMAKUSWITCHSAVE = DESCRIPTOR.message_types_by_name['PlayerDanmakuSwitchSave']
_PLAYERDANMAKUUSEDEFAULTCONFIG = DESCRIPTOR.message_types_by_name['PlayerDanmakuUseDefaultConfig']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_SUBTITLEITEM = DESCRIPTOR.message_types_by_name['SubtitleItem']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_VIDEOMASK = DESCRIPTOR.message_types_by_name['VideoMask']
_VIDEOSUBTITLE = DESCRIPTOR.message_types_by_name['VideoSubtitle']
BuzzwordConfig = _reflection.GeneratedProtocolMessageType('BuzzwordConfig', (_message.Message,), {
  'DESCRIPTOR' : _BUZZWORDCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.BuzzwordConfig)
  })
_sym_db.RegisterMessage(BuzzwordConfig)

BuzzwordShowConfig = _reflection.GeneratedProtocolMessageType('BuzzwordShowConfig', (_message.Message,), {
  'DESCRIPTOR' : _BUZZWORDSHOWCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.BuzzwordShowConfig)
  })
_sym_db.RegisterMessage(BuzzwordShowConfig)

CommandDm = _reflection.GeneratedProtocolMessageType('CommandDm', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDM,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.CommandDm)
  })
_sym_db.RegisterMessage(CommandDm)

DanmakuAIFlag = _reflection.GeneratedProtocolMessageType('DanmakuAIFlag', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUAIFLAG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmakuAIFlag)
  })
_sym_db.RegisterMessage(DanmakuAIFlag)

DanmakuElem = _reflection.GeneratedProtocolMessageType('DanmakuElem', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUELEM,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmakuElem)
  })
_sym_db.RegisterMessage(DanmakuElem)

DanmakuFlag = _reflection.GeneratedProtocolMessageType('DanmakuFlag', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUFLAG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmakuFlag)
  })
_sym_db.RegisterMessage(DanmakuFlag)

DanmakuFlagConfig = _reflection.GeneratedProtocolMessageType('DanmakuFlagConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUFLAGCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmakuFlagConfig)
  })
_sym_db.RegisterMessage(DanmakuFlagConfig)

DanmuDefaultPlayerConfig = _reflection.GeneratedProtocolMessageType('DanmuDefaultPlayerConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUDEFAULTPLAYERCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmuDefaultPlayerConfig)
  })
_sym_db.RegisterMessage(DanmuDefaultPlayerConfig)

DanmuPlayerConfig = _reflection.GeneratedProtocolMessageType('DanmuPlayerConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUPLAYERCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmuPlayerConfig)
  })
_sym_db.RegisterMessage(DanmuPlayerConfig)

DanmuPlayerDynamicConfig = _reflection.GeneratedProtocolMessageType('DanmuPlayerDynamicConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUPLAYERDYNAMICCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmuPlayerDynamicConfig)
  })
_sym_db.RegisterMessage(DanmuPlayerDynamicConfig)

DanmuPlayerViewConfig = _reflection.GeneratedProtocolMessageType('DanmuPlayerViewConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUPLAYERVIEWCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmuPlayerViewConfig)
  })
_sym_db.RegisterMessage(DanmuPlayerViewConfig)

DanmuWebPlayerConfig = _reflection.GeneratedProtocolMessageType('DanmuWebPlayerConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUWEBPLAYERCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DanmuWebPlayerConfig)
  })
_sym_db.RegisterMessage(DanmuWebPlayerConfig)

DmExpoReportReq = _reflection.GeneratedProtocolMessageType('DmExpoReportReq', (_message.Message,), {
  'DESCRIPTOR' : _DMEXPOREPORTREQ,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmExpoReportReq)
  })
_sym_db.RegisterMessage(DmExpoReportReq)

DmExpoReportRes = _reflection.GeneratedProtocolMessageType('DmExpoReportRes', (_message.Message,), {
  'DESCRIPTOR' : _DMEXPOREPORTRES,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmExpoReportRes)
  })
_sym_db.RegisterMessage(DmExpoReportRes)

DmPlayerConfigReq = _reflection.GeneratedProtocolMessageType('DmPlayerConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _DMPLAYERCONFIGREQ,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmPlayerConfigReq)
  })
_sym_db.RegisterMessage(DmPlayerConfigReq)

DmSegConfig = _reflection.GeneratedProtocolMessageType('DmSegConfig', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegConfig)
  })
_sym_db.RegisterMessage(DmSegConfig)

DmSegMobileReply = _reflection.GeneratedProtocolMessageType('DmSegMobileReply', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGMOBILEREPLY,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegMobileReply)
  })
_sym_db.RegisterMessage(DmSegMobileReply)

DmSegMobileReq = _reflection.GeneratedProtocolMessageType('DmSegMobileReq', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGMOBILEREQ,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegMobileReq)
  })
_sym_db.RegisterMessage(DmSegMobileReq)

DmSegOttReply = _reflection.GeneratedProtocolMessageType('DmSegOttReply', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGOTTREPLY,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegOttReply)
  })
_sym_db.RegisterMessage(DmSegOttReply)

DmSegOttReq = _reflection.GeneratedProtocolMessageType('DmSegOttReq', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGOTTREQ,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegOttReq)
  })
_sym_db.RegisterMessage(DmSegOttReq)

DmSegSDKReply = _reflection.GeneratedProtocolMessageType('DmSegSDKReply', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGSDKREPLY,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegSDKReply)
  })
_sym_db.RegisterMessage(DmSegSDKReply)

DmSegSDKReq = _reflection.GeneratedProtocolMessageType('DmSegSDKReq', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGSDKREQ,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmSegSDKReq)
  })
_sym_db.RegisterMessage(DmSegSDKReq)

DmViewReply = _reflection.GeneratedProtocolMessageType('DmViewReply', (_message.Message,), {
  'DESCRIPTOR' : _DMVIEWREPLY,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmViewReply)
  })
_sym_db.RegisterMessage(DmViewReply)

DmViewReq = _reflection.GeneratedProtocolMessageType('DmViewReq', (_message.Message,), {
  'DESCRIPTOR' : _DMVIEWREQ,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmViewReq)
  })
_sym_db.RegisterMessage(DmViewReq)

DmWebViewReply = _reflection.GeneratedProtocolMessageType('DmWebViewReply', (_message.Message,), {
  'DESCRIPTOR' : _DMWEBVIEWREPLY,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.DmWebViewReply)
  })
_sym_db.RegisterMessage(DmWebViewReply)

ExpoReport = _reflection.GeneratedProtocolMessageType('ExpoReport', (_message.Message,), {
  'DESCRIPTOR' : _EXPOREPORT,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.ExpoReport)
  })
_sym_db.RegisterMessage(ExpoReport)

Expression = _reflection.GeneratedProtocolMessageType('Expression', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSION,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.Expression)
  })
_sym_db.RegisterMessage(Expression)

Expressions = _reflection.GeneratedProtocolMessageType('Expressions', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONS,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.Expressions)
  })
_sym_db.RegisterMessage(Expressions)

Period = _reflection.GeneratedProtocolMessageType('Period', (_message.Message,), {
  'DESCRIPTOR' : _PERIOD,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.Period)
  })
_sym_db.RegisterMessage(Period)

InlinePlayerDanmakuSwitch = _reflection.GeneratedProtocolMessageType('InlinePlayerDanmakuSwitch', (_message.Message,), {
  'DESCRIPTOR' : _INLINEPLAYERDANMAKUSWITCH,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.InlinePlayerDanmakuSwitch)
  })
_sym_db.RegisterMessage(InlinePlayerDanmakuSwitch)

PlayerDanmakuAiRecommendedLevel = _reflection.GeneratedProtocolMessageType('PlayerDanmakuAiRecommendedLevel', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUAIRECOMMENDEDLEVEL,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedLevel)
  })
_sym_db.RegisterMessage(PlayerDanmakuAiRecommendedLevel)

PlayerDanmakuAiRecommendedSwitch = _reflection.GeneratedProtocolMessageType('PlayerDanmakuAiRecommendedSwitch', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUAIRECOMMENDEDSWITCH,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedSwitch)
  })
_sym_db.RegisterMessage(PlayerDanmakuAiRecommendedSwitch)

PlayerDanmakuBlockbottom = _reflection.GeneratedProtocolMessageType('PlayerDanmakuBlockbottom', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUBLOCKBOTTOM,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuBlockbottom)
  })
_sym_db.RegisterMessage(PlayerDanmakuBlockbottom)

PlayerDanmakuBlockcolorful = _reflection.GeneratedProtocolMessageType('PlayerDanmakuBlockcolorful', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUBLOCKCOLORFUL,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuBlockcolorful)
  })
_sym_db.RegisterMessage(PlayerDanmakuBlockcolorful)

PlayerDanmakuBlockrepeat = _reflection.GeneratedProtocolMessageType('PlayerDanmakuBlockrepeat', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUBLOCKREPEAT,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuBlockrepeat)
  })
_sym_db.RegisterMessage(PlayerDanmakuBlockrepeat)

PlayerDanmakuBlockscroll = _reflection.GeneratedProtocolMessageType('PlayerDanmakuBlockscroll', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUBLOCKSCROLL,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuBlockscroll)
  })
_sym_db.RegisterMessage(PlayerDanmakuBlockscroll)

PlayerDanmakuBlockspecial = _reflection.GeneratedProtocolMessageType('PlayerDanmakuBlockspecial', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUBLOCKSPECIAL,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuBlockspecial)
  })
_sym_db.RegisterMessage(PlayerDanmakuBlockspecial)

PlayerDanmakuBlocktop = _reflection.GeneratedProtocolMessageType('PlayerDanmakuBlocktop', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUBLOCKTOP,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuBlocktop)
  })
_sym_db.RegisterMessage(PlayerDanmakuBlocktop)

PlayerDanmakuDomain = _reflection.GeneratedProtocolMessageType('PlayerDanmakuDomain', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUDOMAIN,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuDomain)
  })
_sym_db.RegisterMessage(PlayerDanmakuDomain)

PlayerDanmakuEnableblocklist = _reflection.GeneratedProtocolMessageType('PlayerDanmakuEnableblocklist', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUENABLEBLOCKLIST,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuEnableblocklist)
  })
_sym_db.RegisterMessage(PlayerDanmakuEnableblocklist)

PlayerDanmakuOpacity = _reflection.GeneratedProtocolMessageType('PlayerDanmakuOpacity', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUOPACITY,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuOpacity)
  })
_sym_db.RegisterMessage(PlayerDanmakuOpacity)

PlayerDanmakuScalingfactor = _reflection.GeneratedProtocolMessageType('PlayerDanmakuScalingfactor', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUSCALINGFACTOR,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuScalingfactor)
  })
_sym_db.RegisterMessage(PlayerDanmakuScalingfactor)

PlayerDanmakuSeniorModeSwitch = _reflection.GeneratedProtocolMessageType('PlayerDanmakuSeniorModeSwitch', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUSENIORMODESWITCH,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuSeniorModeSwitch)
  })
_sym_db.RegisterMessage(PlayerDanmakuSeniorModeSwitch)

PlayerDanmakuSpeed = _reflection.GeneratedProtocolMessageType('PlayerDanmakuSpeed', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUSPEED,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuSpeed)
  })
_sym_db.RegisterMessage(PlayerDanmakuSpeed)

PlayerDanmakuSwitch = _reflection.GeneratedProtocolMessageType('PlayerDanmakuSwitch', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUSWITCH,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuSwitch)
  })
_sym_db.RegisterMessage(PlayerDanmakuSwitch)

PlayerDanmakuSwitchSave = _reflection.GeneratedProtocolMessageType('PlayerDanmakuSwitchSave', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUSWITCHSAVE,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuSwitchSave)
  })
_sym_db.RegisterMessage(PlayerDanmakuSwitchSave)

PlayerDanmakuUseDefaultConfig = _reflection.GeneratedProtocolMessageType('PlayerDanmakuUseDefaultConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDANMAKUUSEDEFAULTCONFIG,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.PlayerDanmakuUseDefaultConfig)
  })
_sym_db.RegisterMessage(PlayerDanmakuUseDefaultConfig)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.Response)
  })
_sym_db.RegisterMessage(Response)

SubtitleItem = _reflection.GeneratedProtocolMessageType('SubtitleItem', (_message.Message,), {
  'DESCRIPTOR' : _SUBTITLEITEM,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.SubtitleItem)
  })
_sym_db.RegisterMessage(SubtitleItem)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

VideoMask = _reflection.GeneratedProtocolMessageType('VideoMask', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOMASK,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.VideoMask)
  })
_sym_db.RegisterMessage(VideoMask)

VideoSubtitle = _reflection.GeneratedProtocolMessageType('VideoSubtitle', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOSUBTITLE,
  '__module__' : 'bilibili.community.service.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.dm.v1.VideoSubtitle)
  })
_sym_db.RegisterMessage(VideoSubtitle)

_DM = DESCRIPTOR.services_by_name['DM']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DMATTRBIT._serialized_start=8246
  _DMATTRBIT._serialized_end=8322
  _SUBTITLETYPE._serialized_start=8324
  _SUBTITLETYPE._serialized_end=8354
  _BUZZWORDCONFIG._serialized_start=79
  _BUZZWORDCONFIG._serialized_end=167
  _BUZZWORDSHOWCONFIG._serialized_start=169
  _BUZZWORDSHOWCONFIG._serialized_end=289
  _COMMANDDM._serialized_start=292
  _COMMANDDM._serialized_end=453
  _DANMAKUAIFLAG._serialized_start=455
  _DANMAKUAIFLAG._serialized_end=535
  _DANMAKUELEM._serialized_start=538
  _DANMAKUELEM._serialized_end=752
  _DANMAKUFLAG._serialized_start=754
  _DANMAKUFLAG._serialized_end=795
  _DANMAKUFLAGCONFIG._serialized_start=797
  _DANMAKUFLAGCONFIG._serialized_end=872
  _DANMUDEFAULTPLAYERCONFIG._serialized_start=875
  _DANMUDEFAULTPLAYERCONFIG._serialized_end=1463
  _DANMUPLAYERCONFIG._serialized_start=1466
  _DANMUPLAYERCONFIG._serialized_end=2232
  _DANMUPLAYERDYNAMICCONFIG._serialized_start=2234
  _DANMUPLAYERDYNAMICCONFIG._serialized_end=2309
  _DANMUPLAYERVIEWCONFIG._serialized_start=2312
  _DANMUPLAYERVIEWCONFIG._serialized_end=2617
  _DANMUWEBPLAYERCONFIG._serialized_start=2620
  _DANMUWEBPLAYERCONFIG._serialized_end=3047
  _DMEXPOREPORTREQ._serialized_start=3049
  _DMEXPOREPORTREQ._serialized_end=3114
  _DMEXPOREPORTRES._serialized_start=3116
  _DMEXPOREPORTRES._serialized_end=3133
  _DMPLAYERCONFIGREQ._serialized_start=3136
  _DMPLAYERCONFIGREQ._serialized_end=4669
  _DMSEGCONFIG._serialized_start=4671
  _DMSEGCONFIG._serialized_end=4718
  _DMSEGMOBILEREPLY._serialized_start=4721
  _DMSEGMOBILEREPLY._serialized_end=4882
  _DMSEGMOBILEREQ._serialized_start=4884
  _DMSEGMOBILEREQ._serialized_end=4987
  _DMSEGOTTREPLY._serialized_start=4989
  _DMSEGOTTREPLY._serialized_end=5082
  _DMSEGOTTREQ._serialized_start=5084
  _DMSEGOTTREQ._serialized_end=5160
  _DMSEGSDKREPLY._serialized_start=5162
  _DMSEGSDKREPLY._serialized_end=5255
  _DMSEGSDKREQ._serialized_start=5257
  _DMSEGSDKREQ._serialized_end=5333
  _DMVIEWREPLY._serialized_start=5336
  _DMVIEWREPLY._serialized_end=6042
  _DMVIEWREQ._serialized_start=6044
  _DMVIEWREQ._serialized_end=6132
  _DMWEBVIEWREPLY._serialized_start=6135
  _DMWEBVIEWREPLY._serialized_end=6627
  _EXPOREPORT._serialized_start=6629
  _EXPOREPORT._serialized_end=6671
  _EXPRESSION._serialized_start=6673
  _EXPRESSION._serialized_end=6773
  _EXPRESSIONS._serialized_start=6775
  _EXPRESSIONS._serialized_end=6848
  _PERIOD._serialized_start=6850
  _PERIOD._serialized_end=6886
  _INLINEPLAYERDANMAKUSWITCH._serialized_start=6888
  _INLINEPLAYERDANMAKUSWITCH._serialized_end=6930
  _PLAYERDANMAKUAIRECOMMENDEDLEVEL._serialized_start=6932
  _PLAYERDANMAKUAIRECOMMENDEDLEVEL._serialized_end=6980
  _PLAYERDANMAKUAIRECOMMENDEDSWITCH._serialized_start=6982
  _PLAYERDANMAKUAIRECOMMENDEDSWITCH._serialized_end=7031
  _PLAYERDANMAKUBLOCKBOTTOM._serialized_start=7033
  _PLAYERDANMAKUBLOCKBOTTOM._serialized_end=7074
  _PLAYERDANMAKUBLOCKCOLORFUL._serialized_start=7076
  _PLAYERDANMAKUBLOCKCOLORFUL._serialized_end=7119
  _PLAYERDANMAKUBLOCKREPEAT._serialized_start=7121
  _PLAYERDANMAKUBLOCKREPEAT._serialized_end=7162
  _PLAYERDANMAKUBLOCKSCROLL._serialized_start=7164
  _PLAYERDANMAKUBLOCKSCROLL._serialized_end=7205
  _PLAYERDANMAKUBLOCKSPECIAL._serialized_start=7207
  _PLAYERDANMAKUBLOCKSPECIAL._serialized_end=7249
  _PLAYERDANMAKUBLOCKTOP._serialized_start=7251
  _PLAYERDANMAKUBLOCKTOP._serialized_end=7289
  _PLAYERDANMAKUDOMAIN._serialized_start=7291
  _PLAYERDANMAKUDOMAIN._serialized_end=7327
  _PLAYERDANMAKUENABLEBLOCKLIST._serialized_start=7329
  _PLAYERDANMAKUENABLEBLOCKLIST._serialized_end=7374
  _PLAYERDANMAKUOPACITY._serialized_start=7376
  _PLAYERDANMAKUOPACITY._serialized_end=7413
  _PLAYERDANMAKUSCALINGFACTOR._serialized_start=7415
  _PLAYERDANMAKUSCALINGFACTOR._serialized_end=7458
  _PLAYERDANMAKUSENIORMODESWITCH._serialized_start=7460
  _PLAYERDANMAKUSENIORMODESWITCH._serialized_end=7506
  _PLAYERDANMAKUSPEED._serialized_start=7508
  _PLAYERDANMAKUSPEED._serialized_end=7543
  _PLAYERDANMAKUSWITCH._serialized_start=7545
  _PLAYERDANMAKUSWITCH._serialized_end=7600
  _PLAYERDANMAKUSWITCHSAVE._serialized_start=7602
  _PLAYERDANMAKUSWITCHSAVE._serialized_end=7642
  _PLAYERDANMAKUUSEDEFAULTCONFIG._serialized_start=7644
  _PLAYERDANMAKUUSEDEFAULTCONFIG._serialized_end=7690
  _RESPONSE._serialized_start=7692
  _RESPONSE._serialized_end=7733
  _SUBTITLEITEM._serialized_start=7736
  _SUBTITLEITEM._serialized_end=7952
  _USERINFO._serialized_start=7954
  _USERINFO._serialized_end=8046
  _VIDEOMASK._serialized_start=8048
  _VIDEOMASK._serialized_end=8131
  _VIDEOSUBTITLE._serialized_start=8133
  _VIDEOSUBTITLE._serialized_end=8244
  _DM._serialized_start=8357
  _DM._serialized_end=9029
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/push.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/push.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x1b\n\rPageBlackList\x12\n\n\x02id\x18\x01 \x01(\t\"\x16\n\x08PageView\x12\n\n\x02id\x18\x01 \x01(\t\"\x9d\x06\n\x0fPushMessageResp\x12\x12\n\nold_taskid\x18\x01 \x01(\x03\x12\x37\n\x03\x62iz\x18\x02 \x01(\x0e\x32*.bilibili.broadcast.v1.PushMessageResp.Biz\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.bilibili.broadcast.v1.PushMessageResp.Type\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07summary\x18\x05 \x01(\t\x12\x0b\n\x03img\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\x41\n\x08position\x18\x08 \x01(\x0e\x32/.bilibili.broadcast.v1.PushMessageResp.Position\x12\x10\n\x08\x64uration\x18\t \x01(\x05\x12\x0e\n\x06\x65xpire\x18\n \x01(\x03\x12\x0e\n\x06taskid\x18\x0b \x01(\t\x12<\n\x0epage_blackList\x18\x0c \x03(\x0b\x32$.bilibili.broadcast.v1.PageBlackList\x12\x32\n\tpage_view\x18\r \x03(\x0b\x32\x1f.bilibili.broadcast.v1.PageView\x12>\n\x0ftarget_resource\x18\x0e \x01(\x0b\x32%.bilibili.broadcast.v1.TargetResource\x12\x13\n\x0bimage_frame\x18\x0f \x01(\x05\x12\x14\n\x0cimage_marker\x18\x10 \x01(\x05\x12\x16\n\x0eimage_position\x18\x11 \x01(\x05\x12\x0b\n\x03job\x18\x12 \x01(\x03\"E\n\x03\x42iz\x12\x0f\n\x0b\x42IZ_UNKNOWN\x10\x00\x12\r\n\tBIZ_VIDEO\x10\x01\x12\x0c\n\x08\x42IZ_LIVE\x10\x02\x12\x10\n\x0c\x42IZ_ACTIVITY\x10\x03\"_\n\x04Type\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x10\n\x0cTYPE_DEFAULT\x10\x01\x12\x0c\n\x08TYPE_HOT\x10\x02\x12\x11\n\rTYPE_REALTIME\x10\x03\x12\x12\n\x0eTYPE_RECOMMEND\x10\x04\"(\n\x08Position\x12\x0f\n\x0bPOS_UNKNOWN\x10\x00\x12\x0b\n\x07POS_TOP\x10\x01\"\xb7\x01\n\x0eTargetResource\x12-\n\x04Type\x18\x01 \x01(\x0e\x32\x1f.bilibili.broadcast.v1.LinkType\x12\x45\n\x08Resource\x18\x02 \x03(\x0b\x32\x33.bilibili.broadcast.v1.TargetResource.ResourceEntry\x1a/\n\rResourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*a\n\x08LinkType\x12\x15\n\x11LINK_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11LINK_TYPE_BANGUMI\x10\x01\x12\x13\n\x0fLINK_TYPE_VIDEO\x10\x02\x12\x12\n\x0eLINK_TYPE_LIVE\x10\x03\x32X\n\x04Push\x12P\n\x0cWatchMessage\x12\x16.google.protobuf.Empty\x1a&.bilibili.broadcast.v1.PushMessageResp0\x01\x62\x06proto3')

_LINKTYPE = DESCRIPTOR.enum_types_by_name['LinkType']
LinkType = enum_type_wrapper.EnumTypeWrapper(_LINKTYPE)
LINK_TYPE_UNKNOWN = 0
LINK_TYPE_BANGUMI = 1
LINK_TYPE_VIDEO = 2
LINK_TYPE_LIVE = 3


_PAGEBLACKLIST = DESCRIPTOR.message_types_by_name['PageBlackList']
_PAGEVIEW = DESCRIPTOR.message_types_by_name['PageView']
_PUSHMESSAGERESP = DESCRIPTOR.message_types_by_name['PushMessageResp']
_TARGETRESOURCE = DESCRIPTOR.message_types_by_name['TargetResource']
_TARGETRESOURCE_RESOURCEENTRY = _TARGETRESOURCE.nested_types_by_name['ResourceEntry']
_PUSHMESSAGERESP_BIZ = _PUSHMESSAGERESP.enum_types_by_name['Biz']
_PUSHMESSAGERESP_TYPE = _PUSHMESSAGERESP.enum_types_by_name['Type']
_PUSHMESSAGERESP_POSITION = _PUSHMESSAGERESP.enum_types_by_name['Position']
PageBlackList = _reflection.GeneratedProtocolMessageType('PageBlackList', (_message.Message,), {
  'DESCRIPTOR' : _PAGEBLACKLIST,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.PageBlackList)
  })
_sym_db.RegisterMessage(PageBlackList)

PageView = _reflection.GeneratedProtocolMessageType('PageView', (_message.Message,), {
  'DESCRIPTOR' : _PAGEVIEW,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.PageView)
  })
_sym_db.RegisterMessage(PageView)

PushMessageResp = _reflection.GeneratedProtocolMessageType('PushMessageResp', (_message.Message,), {
  'DESCRIPTOR' : _PUSHMESSAGERESP,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.PushMessageResp)
  })
_sym_db.RegisterMessage(PushMessageResp)

TargetResource = _reflection.GeneratedProtocolMessageType('TargetResource', (_message.Message,), {

  'ResourceEntry' : _reflection.GeneratedProtocolMessageType('ResourceEntry', (_message.Message,), {
    'DESCRIPTOR' : _TARGETRESOURCE_RESOURCEENTRY,
    '__module__' : 'bilibili.broadcast.v1.push_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TargetResource.ResourceEntry)
    })
  ,
  'DESCRIPTOR' : _TARGETRESOURCE,
  '__module__' : 'bilibili.broadcast.v1.push_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TargetResource)
  })
_sym_db.RegisterMessage(TargetResource)
_sym_db.RegisterMessage(TargetResource.ResourceEntry)

_PUSH = DESCRIPTOR.services_by_name['Push']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TARGETRESOURCE_RESOURCEENTRY._options = None
  _TARGETRESOURCE_RESOURCEENTRY._serialized_options = b'8\001'
  _LINKTYPE._serialized_start=1127
  _LINKTYPE._serialized_end=1224
  _PAGEBLACKLIST._serialized_start=88
  _PAGEBLACKLIST._serialized_end=115
  _PAGEVIEW._serialized_start=117
  _PAGEVIEW._serialized_end=139
  _PUSHMESSAGERESP._serialized_start=142
  _PUSHMESSAGERESP._serialized_end=939
  _PUSHMESSAGERESP_BIZ._serialized_start=731
  _PUSHMESSAGERESP_BIZ._serialized_end=800
  _PUSHMESSAGERESP_TYPE._serialized_start=802
  _PUSHMESSAGERESP_TYPE._serialized_end=897
  _PUSHMESSAGERESP_POSITION._serialized_start=899
  _PUSHMESSAGERESP_POSITION._serialized_end=939
  _TARGETRESOURCE._serialized_start=942
  _TARGETRESOURCE._serialized_end=1125
  _TARGETRESOURCE_RESOURCEENTRY._serialized_start=1078
  _TARGETRESOURCE_RESOURCEENTRY._serialized_end=1125
  _PUSH._serialized_start=1226
  _PUSH._serialized_end=1314
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Exp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    bucket: builtins.int
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        bucket: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket",b"bucket","id",b"id"]) -> None: ...
global___Exp = Exp

class Exps(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPS_FIELD_NUMBER: builtins.int
    @property
    def exps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exp]:
        """"""
        pass
    def __init__(self,
        *,
        exps: typing.Optional[typing.Iterable[global___Exp]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exps",b"exps"]) -> None: ...
global___Exps = Exps



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/interfaces/inner-interface/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3bilibili/im/interfaces/inner-interface/v1/api.proto\x12(bilibili.im.interface.inner.interface.v1\"A\n\x07\x42\x61nUser\x12\x0b\n\x03uid\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x05\x12\x0c\n\x04mode\x18\x04 \x01(\x05\"V\n\x0eReqOpBlacklist\x12\x44\n\tban_users\x18\x01 \x03(\x0b\x32\x31.bilibili.im.interface.inner.interface.v1.BanUser\"&\n\x0eRspOpBlacklist\x12\x14\n\x0c\x66\x61iled_users\x18\x01 \x03(\x04\x32\x96\x01\n\x0eInnerInterface\x12\x83\x01\n\rUpdateListInn\x12\x38.bilibili.im.interface.inner.interface.v1.ReqOpBlacklist\x1a\x38.bilibili.im.interface.inner.interface.v1.RspOpBlacklistb\x06proto3')



_BANUSER = DESCRIPTOR.message_types_by_name['BanUser']
_REQOPBLACKLIST = DESCRIPTOR.message_types_by_name['ReqOpBlacklist']
_RSPOPBLACKLIST = DESCRIPTOR.message_types_by_name['RspOpBlacklist']
BanUser = _reflection.GeneratedProtocolMessageType('BanUser', (_message.Message,), {
  'DESCRIPTOR' : _BANUSER,
  '__module__' : 'bilibili.im.interfaces.inner_interface.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interface.inner.interface.v1.BanUser)
  })
_sym_db.RegisterMessage(BanUser)

ReqOpBlacklist = _reflection.GeneratedProtocolMessageType('ReqOpBlacklist', (_message.Message,), {
  'DESCRIPTOR' : _REQOPBLACKLIST,
  '__module__' : 'bilibili.im.interfaces.inner_interface.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interface.inner.interface.v1.ReqOpBlacklist)
  })
_sym_db.RegisterMessage(ReqOpBlacklist)

RspOpBlacklist = _reflection.GeneratedProtocolMessageType('RspOpBlacklist', (_message.Message,), {
  'DESCRIPTOR' : _RSPOPBLACKLIST,
  '__module__' : 'bilibili.im.interfaces.inner_interface.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interface.inner.interface.v1.RspOpBlacklist)
  })
_sym_db.RegisterMessage(RspOpBlacklist)

_INNERINTERFACE = DESCRIPTOR.services_by_name['InnerInterface']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BANUSER._serialized_start=97
  _BANUSER._serialized_end=162
  _REQOPBLACKLIST._serialized_start=164
  _REQOPBLACKLIST._serialized_end=250
  _RSPOPBLACKLIST._serialized_start=252
  _RSPOPBLACKLIST._serialized_end=290
  _INNERINTERFACE._serialized_start=293
  _INNERINTERFACE._serialized_end=443
# @@protoc_insertion_point(module_scope)
